@@ -93,7 +93,7 @@ class DataCounterResetter(QtGui.QWidget):
     
     def addEvent(self, editing=False, loading=False):
         self.editing = False
-        self.newEventDialog = QtGui.QDialog()
+        self.newEventDialog = QtGui.QDialog(self)
         self.newEventDialog.setWindowTitle("Add event")
         
         self.typePicker = QtGui.QComboBox()
@@ -168,17 +168,17 @@ class DataCounterResetter(QtGui.QWidget):
         self.addButton = QtGui.QPushButton("Add")
         self.connect(self.addButton, QtCore.SIGNAL("clicked()"),
                      self.setAlarmEvent)
-        dateHBox = QtGui.QHBoxLayout()
+        dateHBox = QtGui.QHBoxLayout(self)
         dateHBox.addWidget(self.typePicker)
         dateHBox.addWidget(self.intervalPicker)
         dateHBox.addWidget(self.dateButton)
         dateHBox.addWidget(self.weekdayButton)
         dateHBox.addWidget(self.timeButton)
-        nameAddHBox = QtGui.QHBoxLayout()
+        nameAddHBox = QtGui.QHBoxLayout(self)
         nameAddHBox.addWidget(self.eventName)
         nameAddHBox.addWidget(self.addButton)
-        inputFieldHBox = QtGui.QHBoxLayout()
-        inputField2HBox = QtGui.QHBoxLayout()
+        inputFieldHBox = QtGui.QHBoxLayout(self)
+        inputField2HBox = QtGui.QHBoxLayout(self)
         inputFieldHBox.addWidget(self.eventDbusInterface)
         inputFieldHBox.addWidget(self.eventDbusService)
         inputFieldHBox.addWidget(self.eventDbusPath)
@@ -186,7 +186,7 @@ class DataCounterResetter(QtGui.QWidget):
         inputField2HBox.addWidget(self.eventDbusArgs)
         inputFieldHBox.addWidget(self.eventExec)
         inputFieldHBox.addWidget(self.eventBuiltin)
-        newEventVBox = QtGui.QVBoxLayout()
+        newEventVBox = QtGui.QVBoxLayout(self)
         newEventVBox.addLayout(dateHBox)
         newEventVBox.addLayout(nameAddHBox)
         newEventVBox.addLayout(inputFieldHBox)
